==> omegat_2.3.0.1+dfsg.orig.tar.gz: omegat-2.3.0.1+dfsg/src/org/omegat/core/events/IEntryEventListener.java <==
/**************************************************************************
 OmegaT - Computer Assisted Translation (CAT) tool 
          with fuzzy matching, translation memory, keyword search, 
          glossaries, and translation leveraging into updated projects.

 Copyright (C) 2008 Alex Buloichik
               Home page: http://www.omegat.org/
               Support center: http://groups.yahoo.com/group/OmegaT/

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 **************************************************************************/
package org.omegat.core.events;

import org.omegat.core.data.SourceTextEntry;

/**
 * Listener interface for entry change events.
 * 
 * @author Alex Buloichik (alex73mail@gmail.com)
 */
public interface IEntryEventListener {
    /**
     * Called on new file displayed.
     * 
     * @param activeFileName
     *            new active file name
     */
    void onNewFile(String activeFileName);

    /**
     * Called on new entry activated or current entry deactivated.
     * 
     * @param newEntry
     *            new entry instance which activated, or null if entry
     *            deactivated
     */
    void onEntryActivated(SourceTextEntry newEntry);
}

==> omegat_3.6.0.10+dfsg.orig.tar.gz: omegat-3.6.0.10+dfsg/src/org/omegat/core/events/IEntryEventListener.java <==
/**************************************************************************
 OmegaT - Computer Assisted Translation (CAT) tool 
          with fuzzy matching, translation memory, keyword search, 
          glossaries, and translation leveraging into updated projects.

 Copyright (C) 2008 Alex Buloichik
               Home page: http://www.omegat.org/
               Support center: http://groups.yahoo.com/group/OmegaT/

 This file is part of OmegaT.

 OmegaT is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.

 OmegaT is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **************************************************************************/
package org.omegat.core.events;

import org.omegat.core.data.SourceTextEntry;

/**
 * Listener interface for entry change events.
 * 
 * @author Alex Buloichik (alex73mail@gmail.com)
 */
public interface IEntryEventListener {
    /**
     * Called on new file displayed.
     * 
     * @param activeFileName
     *            new active file name
     */
    void onNewFile(String activeFileName);

    /**
     * Called on new entry activated or current entry deactivated.
     * 
     * @param newEntry
     *            new entry instance which activated, or null if entry
     *            deactivated
     */
    void onEntryActivated(SourceTextEntry newEntry);
}
